@@ -1492,6 +1492,9 @@ GVApi::onGetPhones(bool success, const QByteArray &response, QNetworkReply *,
                            (strPName == "weekendAllDay") ||
                            (strPName == "weekendTimes") ||
                            (strPName == "redirectToVoicemail") ||
+                           (strPName == "sharingGroupId") ||
+                           (strPName == "visibility") ||
+                           (strPName == "lastVerificationDate") ||
                            (strPName == "enabledForOthers")) {
                 } else {
                     if (emitLog) {
@@ -1931,7 +1934,8 @@ GVApi::parseDomElement(const QString &domStr,
     while (true) {
         pos = findDomElement (domStr, element, pos, isStart);
         if (-1 == pos) {
-            return "";
+            Q_WARN("Nothing found");
+            return QString();
         }
 
         startingPos = pos;
@@ -1943,7 +1947,8 @@ GVApi::parseDomElement(const QString &domStr,
 
         pos = domStr.indexOf ('>', pos);
         if (-1 == pos) {
-            return "";
+            Q_WARN("No close brace for node start tag?");
+            return QString();
         }
 
         nodeDef = domStr.mid (startingPos, pos - startingPos + 1);
@@ -1971,6 +1976,7 @@ GVApi::parseDomElement(const QString &domStr,
     while (true) {
         pos = findDomElement (domStr, element, pos + element.length(), isStart);
         if (-1 == pos) {
+            Q_WARN("No end to node?");
             break;
         }
 
