@@ -27,6 +27,8 @@ Contact: yuvraaj@gmail.com
 #include "ContactsModel.h"
 #include "InboxModel.h"
 
+#include "O2ContactsStore.h"
+
 CacheDb::CacheDb(QObject *parent /* = NULL*/)
 : QObject (parent)
 {
@@ -96,16 +98,16 @@ CacheDb::cleanup_dangling_temp_ids()
         }
     }
 
+    quint64 del = 0;
     // One entry for all empty paths
     arrPaths += "";
     for (int i = 0; i < arrPaths.length() ; i++) {
-        QString strPath = arrPaths[i];
-        strPath.replace ("'", "''");
-        query.exec(QString("DELETE FROM " GV_TEMP_TABLE " WHERE "
-                    GV_TT_PATH "='%1'").arg(strPath));
+        del += clearTempFileByFile (arrPaths[i]);
     }
+    Q_DEBUG(QString("Deleted %1 entries from the temp link table")
+                .arg(del));
 
-    quint32 del = clearTempFileByFile (UNKNOWN_CONTACT_QRC_PATH);
+    del = clearTempFileByFile (UNKNOWN_CONTACT_QRC_PATH);
     if (0 != del) {
         Q_DEBUG(QString("Deleted %1 links all pointing to the unknown qrc path")
                 .arg (del));
@@ -118,6 +120,13 @@ CacheDb::deinit()
     CacheDbPrivate::deref ();
 }//CacheDb::deinit
 
+O2ContactsStore *
+CacheDb::createContactsStore()
+{
+    CacheDbPrivate &p = CacheDbPrivate::ref ();
+    return new O2ContactsStore(p.settings, this);
+}//CacheDb::createContactsStore
+
 void
 CacheDb::setQuickAndDirty(bool beDirty /* = true*/)
 {
@@ -403,66 +412,6 @@ CacheDb::clearCookies()
     return (rv);
 }//CacheDb::clearCookies
 
-void
-CacheDb::setTFAFlag(bool set)
-{
-    CacheDbPrivate &p = CacheDbPrivate::ref();
-    p.settings->setValue (GV_S_VAR_TFA, set);
-}//CacheDb::setTFAFlag
-
-bool
-CacheDb::getTFAFlag()
-{
-    CacheDbPrivate &p = CacheDbPrivate::ref();
-    return (p.settings->value(GV_S_VAR_TFA).toBool());
-}//CacheDb::getTFAFlag
-
-void
-CacheDb::clearTFAFlag()
-{
-    CacheDbPrivate &p = CacheDbPrivate::ref();
-    p.settings->remove (GV_S_VAR_TFA);
-}//CacheDb::clearTFAFlag
-
-bool
-CacheDb::getAppPass(QString &strPass)
-{
-    QByteArray byD;
-    Lib &lib = Lib::ref();
-    QString strResult;
-    CacheDbPrivate &p = CacheDbPrivate::ref();
-
-    if (p.settings->contains (GV_S_VAR_CPASS)) {
-        strResult = p.settings->value(GV_S_VAR_CPASS).toString();
-        lib.cipher (QByteArray::fromHex (strResult.toLatin1 ()), byD, false);
-        strPass = byD;
-
-        return (true);
-    }
-
-    return (false);
-}//CacheDb::getAppPass
-
-bool
-CacheDb::setAppPass(const QString &strPass)
-{
-    QByteArray byD;
-    Lib &lib = Lib::ref();
-    CacheDbPrivate &p = CacheDbPrivate::ref();
-
-    lib.cipher (strPass.toLatin1 (), byD, true);
-    p.settings->setValue (GV_S_VAR_CPASS, QString (byD.toHex ()));
-
-    return (true);
-}//CacheDb::setAppPass
-
-void
-CacheDb::clearAppPass()
-{
-    CacheDbPrivate &p = CacheDbPrivate::ref();
-    p.settings->remove (GV_S_VAR_CPASS);
-}//CacheDb::clearAppPass
-
 bool
 CacheDb::putTempFile(const QString &strLink, const QString &strPath)
 {
@@ -478,12 +427,15 @@ CacheDb::putTempFile(const QString &strLink, const QString &strPath)
     clearTempFileByLink (strLink, true);
 
     QString strCTime = QDateTime::currentDateTime().toString (Qt::ISODate);
+
+    bool rv =
     query.exec (QString("INSERT INTO " GV_TEMP_TABLE " "
                         "("GV_TT_CTIME","GV_TT_LINK","GV_TT_PATH") VALUES "
                         "('%1','%2','%3')")
                         .arg(strCTime).arg(scrubLink).arg(scrubPath));
+    Q_ASSERT(rv);
 
-    return (true);
+    return (rv);
 }//CacheDb::putTempFile
 
 bool
