@@ -39,6 +39,10 @@ Contact: yuvraaj@gmail.com
 #include "GVNumModel.h"
 #include "ContactNumbersModel.h"
 
+#ifdef DBUS_API
+#include <QtDBus>
+#endif
+
 #ifdef MAIN_QML_PATH
 #error Undefine this shit
 #endif
@@ -117,6 +121,12 @@ QmlMainWindow::QmlMainWindow(QObject *parent)
 , optInboxUpdate(NULL)
 , edContactsUpdateFreq(NULL)
 , edInboxUpdateFreq(NULL)
+#ifdef DBUS_API
+, apiCall(this)
+, apiText(this)
+, apiSettings(this)
+, apiUi(this)
+#endif
 {
 }//QmlMainWindow::QmlMainWindow
 
@@ -137,6 +147,14 @@ QmlMainWindow::init()
 
     IMainWindow::init ();
 
+#ifdef DBUS_API
+    if (!initDBus ()) {
+        qApp->quit ();
+        exit(-1);
+        return;
+    }
+#endif
+
     bool rv = connect(m_view, SIGNAL(viewerStatusChanged(bool)),
                       this, SLOT(onViewerStatusChanged(bool)));
     Q_ASSERT(rv);
@@ -163,6 +181,56 @@ QmlMainWindow::init()
 #endif
 }//QmlMainWindow::init
 
+#ifdef DBUS_API
+bool
+QmlMainWindow::initDBus()
+{
+    QDBusConnection sessionBus = QDBusConnection::sessionBus ();
+    if (!sessionBus.registerService ("org.QGVDial.APIServer")) {
+        Q_WARN("Failed to register Dbus Settings server in this instance... "
+               "Attempting to show the other instance");
+
+        QDBusMessage msg =
+        QDBusMessage::createMethodCall ("org.QGVDial.APIServer",
+                                        "/org/QGVDial/UIServer",
+                                        "org.QGVDial.UIServer",
+                                        "Show");
+        sessionBus.send (msg);
+        return false;
+    }
+
+    if (!apiCall.registerObject ()) {
+        Q_WARN("Failed to register Dbus Call API. Aborting!");
+        return false;
+    }
+    if (!apiText.registerObject ()) {
+        Q_WARN("Failed to register Dbus Text API. Aborting!");
+        return false;
+    }
+    if (!apiSettings.registerObject ()) {
+        Q_WARN("Failed to register Dbus Settings API. Aborting!");
+        return false;
+    }
+    if (!apiUi.registerObject ()) {
+        Q_WARN("Failed to register Dbus UI API. Aborting!");
+        return false;
+    }
+
+    Q_DEBUG("DBus API registered!");
+
+    connect(&apiUi, SIGNAL(sigShow()), this, SLOT(onSigShow()));
+
+    return true;
+}//QmlMainWindow::initDBus
+
+void
+QmlMainWindow::onSigShow()
+{
+    Q_DEBUG("DBus API: Show!");
+    m_view->show();
+}//QmlMainWindow::onSigShow
+#endif
+
 QObject *
 QmlMainWindow::getQMLObject(const char *pageName)
 {
@@ -622,8 +690,9 @@ void
 QmlMainWindow::uiShowContactDetails(const ContactInfo &cinfo)
 {
     QMetaObject::invokeMethod (mainPageStack, "showContactDetails",
-                               Q_ARG (QVariant, QVariant(cinfo.strPhotoPath)),
-                               Q_ARG (QVariant, QVariant(cinfo.strTitle)));
+                               Q_ARG(QVariant, QVariant(cinfo.strPhotoPath)),
+                               Q_ARG(QVariant, QVariant(cinfo.strTitle)),
+                               Q_ARG(QVariant, QVariant(cinfo.strNotes)));
 }//QmlMainWindow::uiShowContactDetails
 
 void
