@@ -29,8 +29,10 @@ Contact: yuvraaj@gmail.com
 
 #if QT_VERSION >= 0x050000
 #include <QtWidgets>
+#include <QtWebKitWidgets/QWebView>
 #define PHONON_ENABLED 0
 #else
+#include <QtWebKit/QtWebKit>
 #define PHONON_ENABLED 1
 #endif
 
