@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -68,7 +68,9 @@ Contact: yuvraaj@gmail.com
 // Stopped using webkit for almost everything
 //#define GV_S_VALUE_DB_VER   "2011-12-28 23:50:30"
 // Database speed improvements
-#define GV_S_VALUE_DB_VER   "2012-01-02 00:27:56"
+//#define GV_S_VALUE_DB_VER   "2012-01-02 00:27:56"
+// Registered numbers table changed to get more fields
+#define GV_S_VALUE_DB_VER   "2013-04-15 16:49:28"
 ////////////////////////////////////////////////////////////////////////////////
 // Started using versioning for the settings
 //#define GV_SETTINGS_VER     "2011-05-13 16:33:50"
@@ -95,10 +97,24 @@ Contact: yuvraaj@gmail.com
 
 #define GV_L_TYPE_NUMBER    "contact number"
 ///////////////////////// GV registered numbers table //////////////////////////
-#define GV_REG_NUMS_TABLE   "gvregnumbers"
-#define GV_RN_NAME          "name"
-#define GV_RN_NUM           "number"
-#define GV_RN_TYPE          "type"
+#define GV_REG_NUMS_TABLE       "gvregnumbers"
+#define GV_RN_NAME              "name"
+#define GV_RN_NUM               "number"
+#define GV_RN_TYPE              "type"
+#define GV_RN_FLAGS             "flags"
+#define GV_RN_FWDCOUNTRY        "forwardingCountry"
+#define GV_RN_DISPUNVERIFYDT    "displayUnverifyScheduledDateTime"
+
+#define GV_RN_F_ACTIVE              (1 << 0)
+#define GV_RN_F_VERIFIED            (1 << 1)
+#define GV_RN_F_INVERIFICATION      (1 << 2)
+#define GV_RN_F_REVERIFYNEEDED      (1 << 3)
+#define GV_RN_F_SMSENABLED          (1 << 4)
+#define GV_RN_F_TELEPHONYVERIFIED   (1 << 5)
+///////////////////////////// Call initiator table /////////////////////////////
+#define GV_CI_TABLE             "call_initiator_table"
+#define GV_CI_ID                "ID"
+#define GV_CI_NUMBER            "number"
 //////////////////////////////// GV inbox table ////////////////////////////////
 #define GV_INBOX_TABLE      "gvinbox"
 #define GV_IN_ID            "id"
